The methods variables(), iteration_ids(), chain_ids(), and draw_ids() return
vectors of all variables, iterations, chains, and draws, respectively. In
contrast, the methods nvariables(), niterations(), nchains(), and
ndraws() return the number of variables, iterations, chains, and draws,
respectively.
variables(x) <- value allows you to modify the vector of variable names,
similar to how names(x) <- value works for vectors and lists. For renaming
specific variables, rename_variables() may offer a more convenient approach.