Learn R Programming

posterior (version 1.7.0)

qgeneralized_pareto: Quantile function for the generalized Pareto distribution

Description

Computes the quantile function for a generalized Pareto distribution with location mu, scale sigma, and shape k.

Usage

qgeneralized_pareto(
  p,
  mu = 0,
  sigma = 1,
  k = 0,
  lower.tail = TRUE,
  log.p = FALSE
)

Value

A numeric vector of quantiles.

Arguments

p

Numeric vector of probabilities.

mu

Location parameter.

sigma

Scale parameter (must be positive).

k

Shape parameter.

lower.tail

Logical; if TRUE (default), probabilities are P[X <= x].

log.p

Logical; if TRUE, probabilities are given as log(p).

Examples

Run this code
qgeneralized_pareto(p = c(0.1, 0.5, 0.9), mu = 0, sigma = 1, k = 0.2)

Run the code above in your browser using DataLab