Learn R Programming

posterior (version 1.2.1)

thin_draws: Thin draws objects

Description

Thin draws objects to reduce their size and autocorrelation in the chains.

Usage

thin_draws(x, thin, ...)

# S3 method for draws thin_draws(x, thin, ...)

Arguments

x

(draws) A draws object or another R object for which the method is defined.

thin

(positive integer) The period for selecting draws.

...

Arguments passed to individual methods (if applicable).

Value

A draws object of the same class as x.

Examples

Run this code
# NOT RUN {
x <- example_draws()
niterations(x)

x <- thin_draws(x, thin = 5)
niterations(x)

# }

Run the code above in your browser using DataLab