Estimate Pareto k value by fitting a Generalized Pareto
Distribution to one or two tails of x. This can be used to estimate
the number of fractional moments that is useful for convergence
diagnostics. For further details see Vehtari et al. (2022).
khat estimated Generalized Pareto Distribution shape parameter k
Arguments
x
(multiple options) One of:
A matrix of draws for a single variable (iterations x chains). See
extract_variable_matrix().
An rvar.
...
Arguments passed to individual methods (if applicable).
tail
(string) The tail to diagnose/smooth:
"right": diagnose/smooth only the right (upper) tail
"left": diagnose/smooth only the left (lower) tail
"both": diagnose/smooth both tails and return the maximum k-hat value
The default is "both".
r_eff
(numeric) relative effective sample size estimate. If
r_eff is omitted, it will be calculated assuming the draws are
from MCMC.
ndraws_tail
(numeric) number of draws for the tail. If
ndraws_tail is not specified, it will be calculated as
ceiling(3 * sqrt(length(x) / r_eff)) if length(x) > 225 and
length(x) / 5 otherwise (see Appendix H in Vehtari et al. (2022)).
verbose
(logical) Should diagnostic messages be printed? If
TRUE, messages related to Pareto diagnostics will be
printed. Default is FALSE.
References
Aki Vehtari, Daniel Simpson, Andrew Gelman, Yuling Yao and
Jonah Gabry (2022). Pareto Smoothed Importance Sampling.
arxiv:arXiv:1507.02646