Learn R Programming

posterior (version 1.2.1)

print.draws_rvars: Print draws_rvars objects

Description

Pretty printing for draws_rvars objects.

Usage

# S3 method for draws_rvars
print(
  x,
  digits = 2,
  max_variables = getOption("posterior.max_variables", 8),
  summary = getOption("posterior.rvar_summary", "mean_sd"),
  reserved = FALSE,
  ...
)

Arguments

x

(draws) A draws object or another R object for which the method is defined.

digits

(nonnegative integer) The minimum number of significant digits to print.

max_variables

(positive integer) The maximum number of variables to print. Can be controlled globally via the "posterior.max_variables" option.

summary

(string) The style of summary to display: "mean_sd" displays mean<U+00B1>sd, "median_mad" displays median<U+00B1>mad. If NULL, getOption("posterior.rvar_summary") is used (default "mean_sd).

reserved

(logical) Should reserved variables be included in the output? Defaults to FALSE. See reserved_variables for an overview of currently reserved variable names.

...

Further arguments passed to the underlying print() methods.

Value

A draws object of the same class as x.

Examples

Run this code
# NOT RUN {
x <- as_draws_rvars(example_draws())
print(x)

# }

Run the code above in your browser using DataLab