For format(), a character vector of the same dimensions as x where each
entry is of the form "mean±sd" or "median±mad", depending on the value
of summary.
Arguments
x, object
(rvar) The rvar to print.
...
Further arguments passed to the underlying print() methods.
summary
(string) The style of summary to display: "mean_sd" displays
mean±sd, "median_mad" displays median±mad. If NULL,
getOption("posterior.rvar_summary") is used (default "mean_sd).
digits
(nonnegative integer) The minimum number of significant digits
to print.
color
(logical) Whether or not to use color when formatting the
output. If TRUE, the pillar::style_num() functions may be used to
produce strings containing control sequences to produce colored output on
the terminal.
vec.len
(nonnegative integer) How many 'first few' elements are
displayed of each vector. If NULL, defaults to
getOption("str")$vec.len, which defaults to 4.
indent.str
(string) The indentation string to use.
nest.lev
(nonnegative integer) Current nesting level in the recursive
calls to str().
give.attr
(logical) If TRUE (default), show attributes as sub
structures.
Details
print() and str() print out rvar objects by summarizing each element
in the random variable with either its mean±sd or median±mad, depending on
the value of summary. Both functions use the format() implementation for
rvar objects under the hood, which returns a character vector in the
mean±sd or median±mad form.