powered by
Computes the quantile function for a generalized Pareto distribution with location mu, scale sigma, and shape k.
mu
sigma
k
qgeneralized_pareto( p, mu = 0, sigma = 1, k = 0, lower.tail = TRUE, log.p = FALSE )
A numeric vector of quantiles.
Numeric vector of probabilities.
Location parameter.
Scale parameter (must be positive).
Shape parameter.
Logical; if TRUE (default), probabilities are P[X <= x].
TRUE
P[X <= x]
Logical; if TRUE, probabilities are given as log(p).
log(p)
qgeneralized_pareto(p = c(0.1, 0.5, 0.9), mu = 0, sigma = 1, k = 0.2)
Run the code above in your browser using DataLab