powered by
draws
Thin draws objects to reduce their size and autocorrelation in the chains.
thin_draws(x, thin, ...)# S3 method for draws thin_draws(x, thin, ...)
# S3 method for draws thin_draws(x, thin, ...)
(draws) A draws object or another R object for which the method is defined.
(positive integer) The period for selecting draws.
Arguments passed to individual methods (if applicable).
A draws object of the same class as x.
x
# NOT RUN { x <- example_draws() niterations(x) x <- thin_draws(x, thin = 5) niterations(x) # }
Run the code above in your browser using DataLab